@@ -62,6 +62,9 @@ def extractDocFromBody(node):
         if Options.hasPythonFlagNoDocStrings():
             doc = None
 
+    if doc is not None and python_version >= 0x3D0:
+        doc = doc.lstrip()
+
     return body, doc
 
 
@@ -128,7 +131,7 @@ def detectFunctionBodyKind(nodes, start_value=None):
             for name, field in ast.iter_fields(node):
                 if name in ("name", "body"):
                     pass
-                elif name in ("bases", "decorator_list", "keywords"):
+                elif name in ("bases", "decorator_list", "keywords", "type_params"):
                     for child in field:
                         _check(child)
                 elif name == "starargs":
@@ -145,7 +148,7 @@ def detectFunctionBodyKind(nodes, start_value=None):
             for name, field in ast.iter_fields(node):
                 if name in ("name", "body"):
                     pass
-                elif name in ("bases", "decorator_list"):
+                elif name in ("bases", "decorator_list", "type_params"):
                     for child in field:
                         _check(child)
                 elif name == "args":
@@ -197,7 +200,10 @@ def detectFunctionBodyKind(nodes, start_value=None):
                 if name in ("name", "body", "comparators"):
                     pass
                 elif name == "generators":
-                    _check(field[0].iter)
+                    if python_version < 0x3B0:
+                        _check(field[0].iter)
+                    else:
+                        _check(field[0])
                 elif name in ("body", "elt"):
                     _check(field)
                 else:
@@ -288,6 +294,8 @@ def setBuildingDispatchers(path_args3, path_args2, path_args1):
 
 
 def buildNode(provider, node, source_ref, allow_none=False):
+    # too many exception handlers, pylint: disable=too-many-branches
+
     if node is None and allow_none:
         return None
 
@@ -327,6 +335,9 @@ def buildNode(provider, node, source_ref, allow_none=False):
         # we got interrupted.
         optimization_logger.info("Interrupted at '%s'." % source_ref)
         raise
+    except SystemExit:
+        optimization_logger.warning("Problem at '%s'." % source_ref.getAsString())
+        raise
     except:
         optimization_logger.warning(
             "Problem at '%s' with %s." % (source_ref.getAsString(), ast.dump(node))
